fn_mrca_divergence_over_time<-function(mrca_divs,name,fn_mrca_divergence_over_time_dir,systime){
  
	#if(class(seqs)=='list'){
		
	#mrca_divs<-setNames(lapply(seqs,fn_mrca_div),name)
	
  #stop if not enough sequences
  nas<-which(sapply(mrca_divs,function(i) is.na(i[[1]])[1])==T)
  if (length(nas)>0){
    print(paste0('Not enough sequences for ',name[nas],' '))
    mrca_divs<-mrca_divs[-nas]
    name<-name[-nas]
  }
  
	#set colors
	subtype_cols<-setNames(viridis::turbo(25),c('01_AE','01B','01BC','02_AG','02A','02A1','07_BC','08_BC','107','11_cpx','35_A1D','63_02A6','A1','A1C','A1CD','A1D','A6','B','BC','BF1','C','D','F1','G','O'))
	set_cols<-subtype_cols[which(names(subtype_cols)%in%name)]
	
  #more than one subtype/CRF
  if(length(mrca_divs)>1){
    
	#plot divergence curves
	xrange<-range(sapply(mrca_divs,function(x) range(x$dates)))
	ymax<-max(sapply(mrca_divs,function(x) max(x$N_div)))
	
	par(mfrow=c(1,2),mar=c(3,4,1,1))
	
	#substitutions per year
	cis<-sapply(mrca_divs,function(h) h$sub_rate_ci)
	cis[cis<0]<-0
	ylim=c(0,max(cis))
	sub_rates<-sapply(mrca_divs,function(h) h$sub_rate)
	b<-barplot(ifelse(sub_rates<0,NA,sub_rates),
	col=subtype_cols,ylim=ylim,ann=F,axes=F)
	arrows(b,cis[1,],b,cis[2,],length=0.05,angle=90,code=3)
	axis(2,las=2,mgp=c(3,0.5,0))
	mtext('AA subsitutions per year',2,3)
	
	
	#mrca divergence over time
	plot(1,1,pch=NA,xlim=xrange,ylim=c(0,ymax),ann=F,axes=F)
	nu<-sapply(seq_along(mrca_divs),function(y){
		points(mrca_divs[[y]]$N_div~mrca_divs[[y]]$dates,
		col=subtype_cols[y],pch=20,cex=0.5)
		lines(mrca_divs[[y]]$dates,predict(mrca_divs[[y]]$model),
		col=subtype_cols[y],lwd=3)
	})
	axis(1,mgp=c(3,0.5,0))
	mtext('MRCA divergence',2,3)
	axis(2,las=2,mgp=c(3,0.5,0))
	mtext('Year',1,3)
	
	imagefile<-paste0(fn_mrca_divergence_over_time_dir,'/mrca_div_',systime,'.tiff')
	ragg::agg_tiff(file = imagefile,width=4*length(mrca_divs),height=10,units="in",res=300)
	dev.set(which = 2)
	dev.copy(which = 4)
	dev.off()
	
	#align MRCAs
	mrca_seqs<-mrca_divs[[1]]$mrca_seq
	for(a in 2:length(mrca_divs)){
		mrca_seqs<-aphid::align(mrca_seqs,mrca_divs[[a]]$mrca_seq)
		}
	#rownames(mrca_seqs)<-sub_names
	rownames(mrca_seqs)<-name
	mrca_seqs<-as.AAbin(mrca_seqs)
		
	#compile mrca stats
	c()->mrca_tab
	for(b in 1:length(mrca_divs)){
	#r<-paste0(sub_names[b],'.',rownames(mrca_divs[[b]]$tab))
	#r<-paste0(names[b],'.',rownames(mrca_divs[[b]]$tab))
	r<-paste0(name[b],'.',rownames(mrca_divs[[b]]$tab))
	rownames(mrca_divs[[b]]$tab)<-r
	mrca_tab<-round(rbind(mrca_tab, mrca_divs[[b]]$tab),3)
	}
	
	}
	else{
	
	#plot divergence curves
	xrange<-range(mrca_divs[[1]]$dates)
	ymax<-max(mrca_divs[[1]]$N_div)
		
	par(mfrow=c(1,2),mar=c(3,4,1,1))
	
	#substitutions per year
	cis<-mrca_divs[[1]]$sub_rate_ci
	ylim=c(0,max(cis))
	b<-barplot(mrca_divs[[1]]$sub_rate,
	col=set_cols,ylim=ylim,ann=F,axes=F,names.arg=names(mrca_divs))
	arrows(b,cis[1],b,cis[2],length=0.05,angle=90,code=3)
	axis(2,las=2,mgp=c(3,0.5,0))
	mtext('AA subsitutions per year',2,3)
	
	#mrca divergence over time
	plot(mrca_divs[[1]]$N_div~mrca_divs[[1]]$dates,
		xlim=xrange,ylim=c(0,ymax),ann=F,axes=F,
		col=set_cols,pch=20,cex=0.5)
		lines(mrca_divs[[1]]$dates,predict(mrca_divs[[1]]$model),
		col=set_cols,lwd=3)
	axis(1,mgp=c(3,0.5,0))
	mtext('MRCA divergence',2,3)
	axis(2,las=2,mgp=c(3,0.5,0))
	mtext('Year',1,3)
	
	imagefile<-paste0(fn_mrca_divergence_over_time_dir,'/mrca_div_',systime,'.tiff')
	#agg_tiff(file = imagefile,width=15,height=8,units="in",res=300)
	ragg::agg_tiff(file = imagefile,width=8,height=10,units="in",res=300)
	dev.set(which = 2)
	dev.copy(which = 4)
	dev.off()
	
	mrca_seqs<-as.matrix(as.AAbin(mrca_divs[[1]]$mrca_seq))
	names(mrca_seqs)<-name
	mrca_tab<-round(mrca_divs[[1]]$tab,3)
	}	
	
	return(list(mrca_seqs=mrca_seqs,mrca_tab=mrca_tab))
	}
